powered by
Removes ties from by adding noise at tied times
addNoiseAtEventTimes(fr, id, from, to)
Longitudinally refined data.table of the input data.table
data.table
fr with random noise added for tiebreaking.
fr
Data on long format
Name of column in dataFr that identifies individuals
dataFr
Name of the variable that contains the name of start state for each at-risk interval
Name of column with stop time of the at risk period
Pål Christie Ryalen <p.c.ryalen@medisin.uio.no>
library(data.table) data(fr1) fr1 <- as.data.table(fr1) fr1 <- addNoiseAtEventTimes(fr1) head(fr1)
Run the code above in your browser using DataLab